boost\_histogram
================

.. automodule:: boost_histogram
   :members:
   :undoc-members:
   :show-inheritance:


.. include:: boost_histogram.axis.rst
.. include:: boost_histogram.cpp.rst


boost\_histogram.accumulators
=============================

.. automodule:: boost_histogram.accumulators
   :members:
   :undoc-members:
   :show-inheritance:

boost\_histogram.numpy
======================

.. automodule:: boost_histogram.numpy
   :members:
   :undoc-members:
   :show-inheritance:

boost\_histogram.storage
========================

.. automodule:: boost_histogram.storage
   :members:
   :undoc-members:
   :show-inheritance:

boost\_histogram.tag
====================

.. automodule:: boost_histogram.tag
   :members:
   :undoc-members:
   :show-inheritance:

boost\_histogram.utils
======================

.. automodule:: boost_histogram.utils
   :members:
   :undoc-members:
   :show-inheritance:

boost\_histogram.version
========================

.. automodule:: boost_histogram.version
   :members:
   :undoc-members:
   :show-inheritance:

